"use strict";

exports.__esModule = true;
exports.getHeight = exports.fileListToArray = exports.generateSampleData = exports.truncateWords = exports.stringToSlug = exports.generateUUID = void 0;

var _uuid = require("uuid");

var sampleData = _interopRequireWildcard(require("../components/sampleFieldsData"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var generateUUID = function generateUUID() {
  return (0, _uuid.v4)();
};

exports.generateUUID = generateUUID;

var stringToSlug = function stringToSlug(str) {
  str = str.replace(/^\s+|\s+$/g, ''); // trim

  str = str.toLowerCase();
  str = truncateWords(str, 4); // remove accents, swap ñ for n, etc

  var from = "àáäâèéëêìíïîòóöôùúüûñç·/_,:;";
  var to = "aaaaeeeeiiiioooouuuunc______";

  for (var i = 0, l = from.length; i < l; i++) {
    str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
  }

  str = str.replace(/[^a-z0-9 -]/g, '') // remove invalid chars
  .replace(/\s+/g, '_') // collapse whitespace and replace by -
  .replace(/-+/g, '_'); // collapse dashes

  return str;
};

exports.stringToSlug = stringToSlug;

var truncateWords = function truncateWords(str, noWords) {
  return str.split(" ").splice(0, noWords).join(" ");
};

exports.truncateWords = truncateWords;

var generateSampleData = function generateSampleData(type, order) {
  var uuid = generateUUID();
  var machineName = type + '-' + Math.round(Date.now() / 1000);

  switch (type) {
    case 'text':
      return sampleData.textField(uuid, machineName, order);

    case 'select':
      return sampleData.selectField(uuid, machineName, order);

    case 'checkbox':
      return sampleData.checkboxField(uuid, machineName, order);

    case 'radio':
      return sampleData.radioField(uuid, machineName, order);

    case 'date':
      return sampleData.dateField(uuid, machineName, order);

    case 'file':
      return sampleData.fileField(uuid, machineName, order);

    case 'survey':
      return sampleData.surveyField(uuid, machineName, order);

    case 'quiz':
      return sampleData.quizField(uuid, machineName, order);

    case 'signature':
      return sampleData.signatureField(uuid, machineName, order);

    case 'content':
      return sampleData.contentField(uuid, machineName, order);

    case 'image':
      return sampleData.imageField(uuid, machineName, order);

    case 'video':
      return sampleData.videoField(uuid, machineName, order);

    case 'list':
      return sampleData.listField(uuid, machineName, order);

    case 'section':
      return sampleData.sectionField(uuid, machineName, order);

    default:
      return sampleData.textField(uuid, machineName, order);
  }
};

exports.generateSampleData = generateSampleData;

var fileListToArray = function fileListToArray(list) {
  var array = [];

  for (var i = 0; i < list.length; i++) {
    array.push(list.item(i));
  }

  return array;
};

exports.fileListToArray = fileListToArray;

var getHeight = function getHeight(toolbar, hasTabs) {
  if (toolbar === void 0) {
    toolbar = false;
  }

  if (hasTabs === void 0) {
    hasTabs = true;
  }

  var initial = 0;

  if (toolbar) {
    initial += 66;
  }

  if (hasTabs) {
    initial += 47;
  }

  return screen.height - initial - 180;
};

exports.getHeight = getHeight;